#!/bin/bash
#
# Normally, editing this script should not be required.
#
# To specify an alternative Java Runtime Environment, uncomment the following line and edit the path
#SMARTSYNCHRONIZE_JAVA_HOME=/usr/lib/java

# If you experience problems, e.g. incorrectly painted windows, try to uncomment one of the following two lines
#export AWT_TOOLKIT=MToolkit
#export AWT_TOOLKIT=XToolkit

if [ "$SMARTSYNCHRONIZE_JAVA_HOME" = "" ] ; then
    SMARTSYNCHRONIZE_JAVA_HOME=$JAVA_HOME
fi

_JAVA_EXEC="java"
if [ "$SMARTSYNCHRONIZE_JAVA_HOME" != "" ] ; then
    _TMP="$SMARTSYNCHRONIZE_JAVA_HOME/bin/java"
    if [ -f "$_TMP" ] ; then
        if [ -x "$_TMP" ] ; then
            _JAVA_EXEC="$_TMP"
        else
            echo "Warning: $_TMP is not executable"
        fi
    else
        echo "Warning: $_TMP does not exist"
    fi
fi

if ! which "$_JAVA_EXEC" >/dev/null ; then
    echo "Error: No java environment found"
    exit 1
fi

#
# Resolve the location of the SmartSynchronize installation.
# This includes resolving any symlinks.
PRG=$0
while [ -h "$PRG" ]; do
    ls=`ls -ld "$PRG"`
    link=`expr "$ls" : '^.*-> \(.*\)$' 2>/dev/null`
    if expr "$link" : '^/' 2> /dev/null >/dev/null; then
        PRG="$link"
    else
        PRG="`dirname "$PRG"`/$link"
    fi
done

SMARTSYNCHRONIZE_BIN=`dirname "$PRG"`

# absolutize dir
oldpwd=`pwd`
cd "${SMARTSYNCHRONIZE_BIN}"
SMARTSYNCHRONIZE_BIN=`pwd`
cd "${oldpwd}"

SMARTSYNCHRONIZE_HOME=`dirname "$SMARTSYNCHRONIZE_BIN"`

# VM-options
# set maximum memory: change -Xmx value if necessary
_VM_OPTIONS="$_VM_OPTIONS -Xmx256m"

# the following line is to work-around bug 6875866 of Java 1.6.0_20 on Intel Nehalem CPUs, e.g. Core i7
"$_JAVA_EXEC" -XX:-UseSSE42Intrinsics -version >/dev/null 2>/dev/null
if [ $? = 0 ] ; then
  echo "Disabling SSE42Intrinsics to work-around bug 6875866."
  _VM_OPTIONS="$_VM_OPTIONS -XX:-UseSSE42Intrinsics"
fi

"$_JAVA_EXEC" $_VM_OPTIONS -jar "$SMARTSYNCHRONIZE_HOME/lib/smartsynchronize.jar" "--pwd:$oldpwd" "$@"
